==> jc-1.4.0.tar.gz: java__5fcup/lalr__5ftransition.h <==
// public class java_cup.lalr_transition

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ef1d81778dfa9018 java__5fcup_lalr__5ftransition

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_lalr__5ftransition_H_
#define _JC_java__5fcup_lalr__5ftransition_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java__5fcup_lalr__5fstate$object;
struct _jc_java__5fcup_lalr__5ftransition$object;
struct _jc_java__5fcup_symbol$object;

// Typedefs
typedef struct _jc_java__5fcup_lalr__5ftransition$sub_refs	_jc_java__5fcup_lalr__5ftransition$sub_refs;
typedef struct _jc_java__5fcup_lalr__5ftransition$sub_nonrefs	_jc_java__5fcup_lalr__5ftransition$sub_nonrefs;
typedef struct _jc_java__5fcup_lalr__5ftransition$refs	_jc_java__5fcup_lalr__5ftransition$refs;
typedef struct _jc_java__5fcup_lalr__5ftransition$nonrefs	_jc_java__5fcup_lalr__5ftransition$nonrefs;
typedef struct _jc_java__5fcup_lalr__5ftransition$object	_jc_java__5fcup_lalr__5ftransition$object;

typedef const struct _jc_java__5fcup_lalr__5ftransition$vmethods	_jc_java__5fcup_lalr__5ftransition$vmethods;
typedef const struct _jc_java__5fcup_lalr__5ftransition$vtable	_jc_java__5fcup_lalr__5ftransition$vtable;
typedef const struct _jc_java__5fcup_lalr__5ftransition$vtype	_jc_java__5fcup_lalr__5ftransition$vtype;

// Constructors
extern void _jc_java__5fcup_lalr__5ftransition$method$_init$1396bb1f428d09d0(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *, struct _jc_java__5fcup_symbol$object *, struct _jc_java__5fcup_lalr__5fstate$object *);
extern void _jc_java__5fcup_lalr__5ftransition$method$_init$a517e5a9b80f481d(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *, struct _jc_java__5fcup_symbol$object *, struct _jc_java__5fcup_lalr__5fstate$object *, struct _jc_java__5fcup_lalr__5ftransition$object *);

// Virtual methods
extern struct _jc_java__5fcup_lalr__5ftransition$object *_jc_java__5fcup_lalr__5ftransition$method$next$988d060d78f36cc4(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *);
extern struct _jc_java__5fcup_symbol$object *_jc_java__5fcup_lalr__5ftransition$method$on__5fsymbol$d719c2c30f048a20(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *);
extern struct _jc_java_lang_String$object *_jc_java__5fcup_lalr__5ftransition$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *);
extern struct _jc_java__5fcup_lalr__5fstate$object *_jc_java__5fcup_lalr__5ftransition$method$to__5fstate$4ca16468f8c885db(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *);

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_lalr__5ftransition$method_info$next$988d060d78f36cc4;
extern _jc_method _jc_java__5fcup_lalr__5ftransition$method_info$on__5fsymbol$d719c2c30f048a20;
extern _jc_method _jc_java__5fcup_lalr__5ftransition$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_java__5fcup_lalr__5ftransition$method_info$to__5fstate$4ca16468f8c885db;

// Virtual methods structure
struct _jc_java__5fcup_lalr__5ftransition$vmethods {
	struct _jc_java__5fcup_lalr__5ftransition$object	*(*next$988d060d78f36cc4)(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *);
	struct _jc_java__5fcup_symbol$object	*(*on__5fsymbol$d719c2c30f048a20)(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *);
	struct _jc_java__5fcup_lalr__5fstate$object	*(*to__5fstate$4ca16468f8c885db)(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *);
};

// Vtable
struct _jc_java__5fcup_lalr__5ftransition$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_lalr__5ftransition$vmethods	java__5fcup_lalr__5ftransition;
};

// Vtype
struct _jc_java__5fcup_lalr__5ftransition$vtype {
	_jc_type			type;
	_jc_java__5fcup_lalr__5ftransition$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_lalr__5ftransition$sub_refs {
	struct _jc_java__5fcup_symbol$object	*__5fon__5fsymbol;
	struct _jc_java__5fcup_lalr__5fstate$object	*__5fto__5fstate;
	struct _jc_java__5fcup_lalr__5ftransition$object	*__5fnext;
};

// Reference instance fields (object)
struct _jc_java__5fcup_lalr__5ftransition$refs {
    _jc_java__5fcup_lalr__5ftransition$sub_refs	java__5fcup_lalr__5ftransition;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_lalr__5ftransition$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_lalr__5ftransition$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_lalr__5ftransition$sub_nonrefs	java__5fcup_lalr__5ftransition;
};

// Object instance structure
struct _jc_java__5fcup_lalr__5ftransition$object {
	_jc_java__5fcup_lalr__5ftransition$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_lalr__5ftransition$vtype	*vtype;
	_jc_java__5fcup_lalr__5ftransition$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_lalr__5ftransition$vtype _jc_java__5fcup_lalr__5ftransition$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_lalr__5ftransition, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_lalr__5ftransition$class_object;

#endif	/* _JC_java__5fcup_lalr__5ftransition_H_ */

==> jc-1.4.6.tar.gz: java__5fcup/lalr__5ftransition.h <==
// public class java_cup.lalr_transition

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ef1d81778dfa9018 java__5fcup_lalr__5ftransition

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_lalr__5ftransition_H_
#define _JC_java__5fcup_lalr__5ftransition_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java__5fcup_lalr__5fstate$object;
struct _jc_java__5fcup_lalr__5ftransition$object;
struct _jc_java__5fcup_symbol$object;

// Typedefs
typedef struct _jc_java__5fcup_lalr__5ftransition$sub_refs	_jc_java__5fcup_lalr__5ftransition$sub_refs;
typedef struct _jc_java__5fcup_lalr__5ftransition$sub_nonrefs	_jc_java__5fcup_lalr__5ftransition$sub_nonrefs;
typedef struct _jc_java__5fcup_lalr__5ftransition$refs	_jc_java__5fcup_lalr__5ftransition$refs;
typedef struct _jc_java__5fcup_lalr__5ftransition$nonrefs	_jc_java__5fcup_lalr__5ftransition$nonrefs;
typedef struct _jc_java__5fcup_lalr__5ftransition$object	_jc_java__5fcup_lalr__5ftransition$object;

typedef const struct _jc_java__5fcup_lalr__5ftransition$vmethods	_jc_java__5fcup_lalr__5ftransition$vmethods;
typedef const struct _jc_java__5fcup_lalr__5ftransition$vtable	_jc_java__5fcup_lalr__5ftransition$vtable;
typedef const struct _jc_java__5fcup_lalr__5ftransition$vtype	_jc_java__5fcup_lalr__5ftransition$vtype;

// Constructors
extern void _jc_java__5fcup_lalr__5ftransition$method$_init$1396bb1f428d09d0(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *, struct _jc_java__5fcup_symbol$object *, struct _jc_java__5fcup_lalr__5fstate$object *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_lalr__5ftransition$method$_init$a517e5a9b80f481d(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *, struct _jc_java__5fcup_symbol$object *, struct _jc_java__5fcup_lalr__5fstate$object *, struct _jc_java__5fcup_lalr__5ftransition$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java__5fcup_lalr__5ftransition$object *_jc_java__5fcup_lalr__5ftransition$method$next$988d060d78f36cc4(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *) _JC_JCNI_ATTR;
extern struct _jc_java__5fcup_symbol$object *_jc_java__5fcup_lalr__5ftransition$method$on__5fsymbol$d719c2c30f048a20(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java__5fcup_lalr__5ftransition$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *) _JC_JCNI_ATTR;
extern struct _jc_java__5fcup_lalr__5fstate$object *_jc_java__5fcup_lalr__5ftransition$method$to__5fstate$4ca16468f8c885db(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_lalr__5ftransition$method_info$next$988d060d78f36cc4;
extern _jc_method _jc_java__5fcup_lalr__5ftransition$method_info$on__5fsymbol$d719c2c30f048a20;
extern _jc_method _jc_java__5fcup_lalr__5ftransition$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_java__5fcup_lalr__5ftransition$method_info$to__5fstate$4ca16468f8c885db;

// Virtual methods structure
struct _jc_java__5fcup_lalr__5ftransition$vmethods {
	struct _jc_java__5fcup_lalr__5ftransition$object	*(*next$988d060d78f36cc4)(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *) _JC_JCNI_ATTR;
	struct _jc_java__5fcup_symbol$object	*(*on__5fsymbol$d719c2c30f048a20)(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *) _JC_JCNI_ATTR;
	struct _jc_java__5fcup_lalr__5fstate$object	*(*to__5fstate$4ca16468f8c885db)(_jc_env *, struct _jc_java__5fcup_lalr__5ftransition$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java__5fcup_lalr__5ftransition$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_lalr__5ftransition$vmethods	java__5fcup_lalr__5ftransition;
};

// Vtype
struct _jc_java__5fcup_lalr__5ftransition$vtype {
	_jc_type			type;
	_jc_java__5fcup_lalr__5ftransition$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_lalr__5ftransition$sub_refs {
	struct _jc_java__5fcup_symbol$object	*__5fon__5fsymbol;
	struct _jc_java__5fcup_lalr__5fstate$object	*__5fto__5fstate;
	struct _jc_java__5fcup_lalr__5ftransition$object	*__5fnext;
};

// Reference instance fields (object)
struct _jc_java__5fcup_lalr__5ftransition$refs {
    _jc_java__5fcup_lalr__5ftransition$sub_refs	java__5fcup_lalr__5ftransition;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_lalr__5ftransition$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_lalr__5ftransition$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_lalr__5ftransition$sub_nonrefs	java__5fcup_lalr__5ftransition;
};

// Object instance structure
struct _jc_java__5fcup_lalr__5ftransition$object {
	_jc_java__5fcup_lalr__5ftransition$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_lalr__5ftransition$vtype	*vtype;
	_jc_java__5fcup_lalr__5ftransition$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_lalr__5ftransition$vtype _jc_java__5fcup_lalr__5ftransition$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_lalr__5ftransition, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_lalr__5ftransition$class_object;

#endif	/* _JC_java__5fcup_lalr__5ftransition_H_ */
